@@ -18,12 +18,14 @@
  * along with gedit. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <gtk/gtk.h>
 #include "gedit-highlight-mode-dialog.h"
 
+#include <gtk/gtk.h>
+
 struct _GeditHighlightModeDialogPrivate
 {
 	GeditHighlightModeSelector *selector;
+	gulong                      on_language_selected_id;
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (GeditHighlightModeDialog, gedit_highlight_mode_dialog, GTK_TYPE_DIALOG)
@@ -36,13 +38,12 @@ gedit_highlight_mode_dialog_response (GtkDialog *dialog,
 
 	if (response_id == GTK_RESPONSE_OK)
 	{
-		/* The dialog will be destroyed if a language is selected */
+		g_signal_handler_block (priv->selector, priv->on_language_selected_id);
 		gedit_highlight_mode_selector_activate_selected_language (priv->selector);
+		g_signal_handler_unblock (priv->selector, priv->on_language_selected_id);
 	}
-	else
-	{
-		gtk_widget_destroy (GTK_WIDGET (dialog));
-	}
+
+	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
 static void
@@ -50,6 +51,12 @@ on_language_selected (GeditHighlightModeSelector *sel,
                       GtkSourceLanguage          *language,
                       GtkDialog                  *dialog)
 {
+	GeditHighlightModeDialogPrivate *priv = GEDIT_HIGHLIGHT_MODE_DIALOG (dialog)->priv;
+
+	g_signal_handler_block (priv->selector, priv->on_language_selected_id);
+	gedit_highlight_mode_selector_activate_selected_language (priv->selector);
+	g_signal_handler_unblock (priv->selector, priv->on_language_selected_id);
+
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
@@ -75,8 +82,8 @@ gedit_highlight_mode_dialog_init (GeditHighlightModeDialog *dlg)
 	gtk_widget_init_template (GTK_WIDGET (dlg));
 	gtk_dialog_set_default_response (GTK_DIALOG (dlg), GTK_RESPONSE_OK);
 
-	g_signal_connect (dlg->priv->selector, "language-selected",
-	                  G_CALLBACK (on_language_selected), dlg);
+	dlg->priv->on_language_selected_id = g_signal_connect (dlg->priv->selector, "language-selected",
+	                                                       G_CALLBACK (on_language_selected), dlg);
 }
 
 GtkWidget *
